@@ -10,26 +10,28 @@ from __future__ import annotations
 import ast
 import logging
 import os
-from typing import Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 import pynguin.analyses.seeding.testimport.ast_to_statement as ats
 import pynguin.configuration as config
-import pynguin.testcase.variable.variablereference as vr
+import pynguin.ga.testcasechromosome as tcc
+import pynguin.testcase.defaulttestcase as dtc
+import pynguin.testcase.testfactory as tf
 import pynguin.utils.statistics.statistics as stat
-from pynguin.ga.testcasechromosome import TestCaseChromosome
-from pynguin.setup.testcluster import TestCluster
-from pynguin.testcase.defaulttestcase import DefaultTestCase
-from pynguin.testcase.testfactory import TestFactory
 from pynguin.utils import randomness
 from pynguin.utils.statistics.runtimevariable import RuntimeVariable
 
+if TYPE_CHECKING:
+    import pynguin.testcase.variablereference as vr
+    from pynguin.setup.testcluster import TestCluster
+
 
 class _InitialPopulationSeeding:
     """Class for seeding the initial population with previously existing testcases."""
 
     def __init__(self):
         self._logger = logging.getLogger(__name__)
-        self._testcases: List[DefaultTestCase] = []
+        self._testcases: List[dtc.DefaultTestCase] = []
         self._test_cluster: TestCluster
 
     @property
@@ -56,7 +58,7 @@ class _InitialPopulationSeeding:
         Returns:
             The ast tree of the given module.
         """
-        module_name = config.configuration.module_name.split(".")[-1]
+        module_name = config.configuration.module_name.rsplit(".", maxsplit=1)[-1]
         self._logger.debug("Module name: %s", module_name)
         result: List[str] = []
         for root, _, files in os.walk(module_path):
@@ -68,7 +70,7 @@ class _InitialPopulationSeeding:
             if len(result) > 0:
                 self._logger.debug("Module name found: %s", result[0])
                 stat.track_output_variable(RuntimeVariable.SuitableTestModule, True)
-                with open(result[0]) as module_file:
+                with open(result[0], encoding="utf-8") as module_file:
                     return ast.parse(module_file.read())
             else:
                 self._logger.debug("No suitable test module found.")
@@ -107,16 +109,16 @@ class _InitialPopulationSeeding:
 
     def _mutate_testcases_initially(self):
         """Mutates the initial population."""
-        test_factory = TestFactory(self.test_cluster)
+        test_factory = tf.TestFactory(self.test_cluster)
         for _ in range(0, config.configuration.seeding.initial_population_mutations):
             for testcase in self._testcases:
-                testcase_wrapper = TestCaseChromosome(testcase, test_factory)
+                testcase_wrapper = tcc.TestCaseChromosome(testcase, test_factory)
                 testcase_wrapper.mutate()
                 if not testcase_wrapper.test_case.statements:
                     self._testcases.remove(testcase)
 
     @property
-    def seeded_testcase(self) -> DefaultTestCase:
+    def seeded_testcase(self) -> dtc.DefaultTestCase:
         """Provides a random seeded test case.
 
         Returns:
@@ -137,10 +139,10 @@ class _InitialPopulationSeeding:
 # pylint: disable=invalid-name, missing-function-docstring
 class _TestTransformer(ast.NodeVisitor):
     def __init__(self, test_cluster: TestCluster):
-        self._current_testcase: DefaultTestCase = DefaultTestCase()
+        self._current_testcase: dtc.DefaultTestCase = dtc.DefaultTestCase()
         self._current_parsable: bool = True
         self._var_refs: Dict[str, vr.VariableReference] = {}
-        self._testcases: List[DefaultTestCase] = []
+        self._testcases: List[dtc.DefaultTestCase] = []
         self._number_found_testcases: int = 0
         self._test_cluster = test_cluster
 
@@ -152,7 +154,7 @@ class _TestTransformer(ast.NodeVisitor):
 
     def visit_FunctionDef(self, node: ast.FunctionDef) -> Any:
         self._number_found_testcases += 1
-        self._current_testcase = DefaultTestCase()
+        self._current_testcase = dtc.DefaultTestCase()
         self._current_parsable = True
         self._var_refs.clear()
         self.generic_visit(node)
@@ -175,7 +177,8 @@ class _TestTransformer(ast.NodeVisitor):
     def visit_Assert(self, node: ast.Assert) -> Any:
         if (
             self._current_parsable
-            and config.configuration.test_case_output.generate_assertions
+            and config.configuration.test_case_output.assertion_generation
+            != config.AssertionGenerator.NONE
         ):
             if (result := ats.create_assert_stmt(self._var_refs, node)) is not None:
                 assertion, var_ref = result
@@ -184,7 +187,7 @@ class _TestTransformer(ast.NodeVisitor):
                 ).add_assertion(assertion)
 
     @property
-    def testcases(self) -> List[DefaultTestCase]:
+    def testcases(self) -> List[dtc.DefaultTestCase]:
         """Provides the transformed testcases.
 
         Returns:
