@@ -5,30 +5,33 @@
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
 """Provides an observer and statement visitor to create none assertions."""
-from typing import Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Optional
 
 import pynguin.assertion.assertiontraceobserver as ato
 import pynguin.assertion.nonetraceentry as nte
-import pynguin.assertion.outputtrace as ot
-import pynguin.testcase.statements.statement as st
-import pynguin.testcase.statements.statementvisitor as stmt_sv
-import pynguin.testcase.variable.variablereference as vr
-from pynguin.testcase.execution.executioncontext import ExecutionContext
+import pynguin.testcase.statement as st
 from pynguin.utils.type_utils import is_primitive_type
 
+if TYPE_CHECKING:
+    import pynguin.assertion.outputtrace as ot
+    import pynguin.testcase.execution as ex
+    import pynguin.testcase.variablereference as vr
+
 
 class NoneTraceObserver(ato.AssertionTraceObserver[nte.NoneTraceEntry]):
     """An observer that trace the none-ness of variables."""
 
     def before_statement_execution(
-        self, statement: st.Statement, exec_ctx: ExecutionContext
+        self, statement: st.Statement, exec_ctx: ex.ExecutionContext
     ):
         pass
 
     def after_statement_execution(
         self,
         statement: st.Statement,
-        exec_ctx: ExecutionContext,
+        exec_ctx: ex.ExecutionContext,
         exception: Optional[Exception] = None,
     ) -> None:
         if exception is not None:
@@ -40,12 +43,12 @@ class NoneTraceObserver(ato.AssertionTraceObserver[nte.NoneTraceEntry]):
         statement.accept(visitor)
 
 
-class NoneAssertionVisitor(stmt_sv.StatementVisitor):
+class NoneAssertionVisitor(st.StatementVisitor):
     """Simple visitor to create assertions for objects that are None or not None."""
 
     def __init__(
         self,
-        exec_ctx: ExecutionContext,
+        exec_ctx: ex.ExecutionContext,
         variable: vr.VariableReference,
         trace: ot.OutputTrace[nte.NoneTraceEntry],
     ):
@@ -68,6 +71,9 @@ class NoneAssertionVisitor(stmt_sv.StatementVisitor):
     def visit_boolean_primitive_statement(self, stmt) -> None:
         pass
 
+    def visit_enum_statement(self, stmt) -> None:
+        pass
+
     def visit_none_statement(self, stmt) -> None:
         pass
 
