@@ -5,30 +5,33 @@
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
 """Provides an observer and statement visitor to create primitive assertions."""
-from typing import Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Optional
 
 import pynguin.assertion.assertiontraceobserver as ato
-import pynguin.assertion.outputtrace as ot
 import pynguin.assertion.primitivetraceentry as pte
-import pynguin.testcase.statements.statement as st
-import pynguin.testcase.statements.statementvisitor as stmt_sv
-import pynguin.testcase.variable.variablereference as vr
-from pynguin.testcase.execution.executioncontext import ExecutionContext
+import pynguin.testcase.statement as st
 from pynguin.utils.type_utils import is_primitive_type
 
+if TYPE_CHECKING:
+    import pynguin.assertion.outputtrace as ot
+    import pynguin.testcase.execution as ex
+    import pynguin.testcase.variablereference as vr
+
 
 class PrimitiveTraceObserver(ato.AssertionTraceObserver[pte.PrimitiveTraceEntry]):
     """An observer that creates assertions on primitive values."""
 
     def before_statement_execution(
-        self, statement: st.Statement, exec_ctx: ExecutionContext
+        self, statement: st.Statement, exec_ctx: ex.ExecutionContext
     ):
         pass
 
     def after_statement_execution(
         self,
         statement: st.Statement,
-        exec_ctx: ExecutionContext,
+        exec_ctx: ex.ExecutionContext,
         exception: Optional[Exception] = None,
     ) -> None:
         if exception is not None:
@@ -40,7 +43,7 @@ class PrimitiveTraceObserver(ato.AssertionTraceObserver[pte.PrimitiveTraceEntry]
         statement.accept(visitor)
 
 
-class PrimitiveAssertionVisitor(stmt_sv.StatementVisitor):
+class PrimitiveAssertionVisitor(st.StatementVisitor):
     """
     Simple visitor to create primitive assertions.
     Primitive statements are not visited, because something like
@@ -51,7 +54,7 @@ class PrimitiveAssertionVisitor(stmt_sv.StatementVisitor):
 
     def __init__(
         self,
-        exec_ctx: ExecutionContext,
+        exec_ctx: ex.ExecutionContext,
         variable: vr.VariableReference,
         trace: ot.OutputTrace[pte.PrimitiveTraceEntry],
     ):
@@ -77,6 +80,9 @@ class PrimitiveAssertionVisitor(stmt_sv.StatementVisitor):
     def visit_none_statement(self, stmt) -> None:
         pass
 
+    def visit_enum_statement(self, stmt) -> None:
+        pass
+
     def visit_list_statement(self, stmt) -> None:
         pass
 
