@@ -7,16 +7,18 @@
 """Provides a chromosome for a single test case."""
 from __future__ import annotations
 
-from typing import Optional
+from typing import TYPE_CHECKING, Optional
 
 import pynguin.configuration as config
 import pynguin.ga.chromosome as chrom
-import pynguin.ga.chromosomevisitor as cv
-import pynguin.testcase.testcase as tc
-import pynguin.testcase.testfactory as tf
-from pynguin.testcase.execution.executionresult import ExecutionResult
 from pynguin.utils import randomness
 
+if TYPE_CHECKING:
+    import pynguin.ga.chromosomevisitor as cv
+    import pynguin.testcase.testcase as tc
+    import pynguin.testcase.testfactory as tf
+    from pynguin.testcase.execution import ExecutionResult
+
 
 class TestCaseChromosome(chrom.Chromosome):
     """A chromosome that encodes a single test case."""
@@ -81,26 +83,20 @@ class TestCaseChromosome(chrom.Chromosome):
         assert isinstance(
             other, TestCaseChromosome
         ), "Cannot perform crossover with " + str(type(other))
-        offspring = self.clone()
-        offspring.test_case.statements.clear()
-
         assert self._test_factory is not None, "Crossover requires a test factory."
 
-        for i in range(position1):
-            offspring.test_case.add_statement(
-                self.test_case.get_statement(i).clone(offspring.test_case)
-            )
+        offspring_test_case = self.test_case.clone(position1)
 
         for j in range(position2, other.test_case.size()):
             self._test_factory.append_statement(
-                offspring.test_case, other.test_case.get_statement(j)
+                offspring_test_case, other.test_case.get_statement(j)
             )
 
         if (
-            offspring.test_case.size()
+            offspring_test_case.size()
             < config.configuration.search_algorithm.chromosome_length
         ):
-            self._test_case = offspring.test_case
+            self._test_case = offspring_test_case
             self.set_changed(True)
 
     def mutate(self) -> None:
@@ -287,6 +283,14 @@ class TestCaseChromosome(chrom.Chromosome):
             return True
         if not isinstance(other, TestCaseChromosome):
             return False
+        # This condition is playing with fire, but it is required to not lose coverage
+        # information on flaky tests. For more information on this see #169.
+        # Be careful when comparing TestCaseChromosomes!
+        if (left := self._last_execution_result) is not None and (
+            right := other._last_execution_result
+        ) is not None:
+            if left.execution_trace != right.execution_trace:
+                return False
         return self._test_case == other._test_case
 
     def __hash__(self):
