@@ -5,17 +5,21 @@
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
 """An abstract test exporter"""
+from __future__ import annotations
+
 import ast
 import os
 from abc import ABCMeta, abstractmethod
 from pathlib import Path
-from typing import List, Optional, Set, Tuple, Union
+from typing import TYPE_CHECKING, List, Optional, Set, Tuple, Union
 
 import astor
 
-import pynguin.testcase.testcase as tc
 import pynguin.testcase.testcase_to_ast as tc_to_ast
-from pynguin.utils.namingscope import NamingScope
+
+if TYPE_CHECKING:
+    import pynguin.testcase.testcase as tc
+    from pynguin.utils.namingscope import NamingScope
 
 
 # pylint: disable=too-few-public-methods
@@ -56,13 +60,13 @@ class AbstractTestExporter(metaclass=ABCMeta):
         if common_modules is not None:
             for module in common_modules:
                 imports.append(ast.Import(names=[ast.alias(name=module, asname=None)]))
-        for module_name in module_aliases.known_name_indices:
+        for module_name, alias in module_aliases:
             imports.append(
                 ast.Import(
                     names=[
                         ast.alias(
                             name=module_name,
-                            asname=module_aliases.get_name(module_name),
+                            asname=alias,
                         )
                     ]
                 )
@@ -114,6 +118,6 @@ class AbstractTestExporter(metaclass=ABCMeta):
         """
         target = Path(path)
         target.parent.mkdir(parents=True, exist_ok=True)
-        with target.open(mode="w") as file:
+        with target.open(mode="w", encoding="UTF-8") as file:
             file.write("# Automatically generated by Pynguin.\n")
             file.write(astor.to_source(module))
