@@ -8,17 +8,19 @@
 from __future__ import annotations
 
 from abc import ABCMeta, abstractmethod
-from typing import List, Optional, Set, Type
+from typing import TYPE_CHECKING, List, Optional, Set, Type
 
-import pynguin.assertion.assertion as ass
-import pynguin.testcase.statements.statement as stmt
-import pynguin.testcase.testcasevisitor as tcv
-import pynguin.testcase.variable.variablereference as vr
 from pynguin.utils import randomness
 from pynguin.utils.atomicinteger import AtomicInteger
 from pynguin.utils.exceptions import ConstructionFailedException
 from pynguin.utils.type_utils import is_assignable_to, is_type_unknown
 
+if TYPE_CHECKING:
+    import pynguin.assertion.assertion as ass
+    import pynguin.testcase.statement as stmt
+    import pynguin.testcase.testcasevisitor as tcv
+    import pynguin.testcase.variablereference as vr
+
 
 # pylint: disable=too-many-public-methods
 class TestCase(metaclass=ABCMeta):
@@ -92,6 +94,14 @@ class TestCase(metaclass=ABCMeta):
             position: The position of the test case to be removed
         """
 
+    @abstractmethod
+    def remove_statement(self, statement: stmt.Statement) -> None:
+        """Remove the given statement from this test case.
+
+        Args:
+            statement: The statement to remove.
+        """
+
     @abstractmethod
     def chop(self, pos: int) -> None:
         """Remove all statements after a given position.
@@ -148,9 +158,12 @@ class TestCase(metaclass=ABCMeta):
         """
 
     @abstractmethod
-    def clone(self) -> TestCase:
+    def clone(self, limit: Optional[int] = None) -> TestCase:
         """Provides a deep copy of the test case.
 
+        Args:
+            limit: Clone this test case only upto the given number of statements.
+
         Returns:
             A deep copy of this test case  # noqa: DAR202
         """
