@@ -8,24 +8,16 @@
 from __future__ import annotations
 
 import logging
-from typing import Any, Dict, List, Optional, Set, Type, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Type, cast
 
+from ordered_set import OrderedSet
 from typing_inspect import get_args, get_origin
 
 import pynguin.configuration as config
-import pynguin.testcase.statements.collectionsstatements as coll_stmt
-import pynguin.testcase.statements.fieldstatement as f_stmt
-import pynguin.testcase.statements.parametrizedstatements as par_stmt
-import pynguin.testcase.statements.primitivestatements as prim
-import pynguin.testcase.statements.statement as stmt
-import pynguin.testcase.testcase as tc
-import pynguin.testcase.variable.variablereference as vr
+import pynguin.testcase.statement as stmt
 import pynguin.utils.generic.genericaccessibleobject as gao
-from pynguin.setup.testcluster import TestCluster
-from pynguin.typeinference.strategy import InferredSignature
 from pynguin.utils import randomness
 from pynguin.utils.exceptions import ConstructionFailedException
-from pynguin.utils.generic.genericaccessibleobject import GenericAccessibleObject
 from pynguin.utils.type_utils import (
     is_assignable_to,
     is_collection_type,
@@ -34,9 +26,15 @@ from pynguin.utils.type_utils import (
     is_type_unknown,
 )
 
+if TYPE_CHECKING:
+    import pynguin.testcase.testcase as tc
+    import pynguin.testcase.variablereference as vr
+    from pynguin.setup.testcluster import TestCluster
+    from pynguin.typeinference.strategy import InferredSignature
+
 
 # TODO(fk) find better name for this?
-# pylint: disable=too-many-lines  # TODO split this monster!
+# TODO split this monster!
 class TestFactory:
     """A factory for test-case generation.
     This factory does not generate test cases but provides all necessary means to
@@ -51,6 +49,7 @@ class TestFactory:
         self,
         test_case: tc.TestCase,
         statement: stmt.Statement,
+        position: int = -1,
         allow_none: bool = True,
     ) -> None:
         """Appends a statement to a test case.
@@ -58,40 +57,43 @@ class TestFactory:
         Args:
             test_case: The test case
             statement: The statement to append
+            position: The position to insert the statement, default is at the end
+                of the test case
             allow_none: Whether or not parameter variables can hold None values
 
         Raises:
             ConstructionFailedException: if construction of an object failed
         """
-        if isinstance(statement, par_stmt.ConstructorStatement):
+        new_position = test_case.size() if position == -1 else position
+        if isinstance(statement, stmt.ConstructorStatement):
             self.add_constructor(
                 test_case,
                 statement.accessible_object(),
-                position=test_case.size(),
+                position=new_position,
                 allow_none=allow_none,
             )
-        elif isinstance(statement, par_stmt.MethodStatement):
+        elif isinstance(statement, stmt.MethodStatement):
             self.add_method(
                 test_case,
                 statement.accessible_object(),
-                position=test_case.size(),
+                position=new_position,
                 allow_none=allow_none,
             )
-        elif isinstance(statement, par_stmt.FunctionStatement):
+        elif isinstance(statement, stmt.FunctionStatement):
             self.add_function(
                 test_case,
                 statement.accessible_object(),
-                position=test_case.size(),
+                position=new_position,
                 allow_none=allow_none,
             )
-        elif isinstance(statement, f_stmt.FieldStatement):
+        elif isinstance(statement, stmt.FieldStatement):
             self.add_field(
                 test_case,
                 statement.field,
-                position=test_case.size(),
+                position=new_position,
             )
-        elif isinstance(statement, prim.PrimitiveStatement):
-            self.add_primitive(test_case, statement, position=test_case.size())
+        elif isinstance(statement, stmt.PrimitiveStatement):
+            self.add_primitive(test_case, statement, position=new_position)
         else:
             raise ConstructionFailedException(f"Unknown statement type: {statement}")
 
@@ -152,6 +154,13 @@ class TestFactory:
                 position=new_position,
                 recursion_depth=recursion_depth,
             )
+        if isinstance(accessible, gao.GenericEnum):
+            return self.add_enum(
+                test_case,
+                accessible,
+                position=new_position,
+                recursion_depth=recursion_depth,
+            )
         raise ConstructionFailedException(f"Unknown accessible type: {accessible}")
 
     # pylint: disable=too-many-arguments
@@ -204,7 +213,7 @@ class TestFactory:
             new_length = test_case.size()
             position = position + new_length - length
 
-            statement = par_stmt.ConstructorStatement(
+            statement = stmt.ConstructorStatement(
                 test_case=test_case,
                 generic_callable=constructor,
                 args=parameters,
@@ -272,7 +281,7 @@ class TestFactory:
         new_length = test_case.size()
         position = position + new_length - length
 
-        statement = par_stmt.MethodStatement(
+        statement = stmt.MethodStatement(
             test_case=test_case,
             generic_callable=method,
             callee=callee,
@@ -323,7 +332,44 @@ class TestFactory:
             )
         assert callee, "The callee must not be None"
         position = position + test_case.size() - length
-        statement = f_stmt.FieldStatement(test_case, field, callee)
+        statement = stmt.FieldStatement(test_case, field, callee)
+        return test_case.add_statement(statement, position)
+
+    def add_enum(
+        self,
+        test_case: tc.TestCase,
+        enum_: gao.GenericEnum,
+        position: int = -1,
+        recursion_depth: int = 0,
+    ) -> vr.VariableReference:
+        """Adds a primitive based on an enum value at a given position.
+
+        If the position is not given, the enum access will be appended to the end of
+        the test case.  A given recursion depth controls how far the factory searches
+        for suitable parameter values.
+
+        Args:
+            test_case: The test case
+            enum_: The enum to add to the test case
+            position: The position where to put the statement in the test case,
+                defaults to the end of the test case
+            recursion_depth: A recursion limit for the search of values
+
+        Returns:
+            A variable reference to the enum value
+
+        Raises:
+            ConstructionFailedException: if construction of an object failed
+        """
+        self._logger.debug("Adding enum %s", enum_)
+        if recursion_depth > config.configuration.test_creation.max_recursion:
+            self._logger.debug("Max recursion depth reached")
+            raise ConstructionFailedException("Max recursion depth reached")
+
+        if position < 0:
+            position = test_case.size()
+
+        statement = stmt.EnumPrimitiveStatement(test_case, enum_)
         return test_case.add_statement(statement, position)
 
     # pylint: disable=too-many-arguments
@@ -375,7 +421,7 @@ class TestFactory:
         new_length = test_case.size()
         position = position + new_length - length
 
-        statement = par_stmt.FunctionStatement(
+        statement = stmt.FunctionStatement(
             test_case=test_case,
             generic_callable=function,
             args=parameters,
@@ -385,7 +431,7 @@ class TestFactory:
     def add_primitive(
         self,
         test_case: tc.TestCase,
-        primitive: prim.PrimitiveStatement,
+        primitive: stmt.PrimitiveStatement,
         position: int = -1,
     ) -> vr.VariableReference:
         """Adds a primitive statement to the given test case at the given position.
@@ -405,7 +451,7 @@ class TestFactory:
             position = test_case.size()
 
         self._logger.debug("Adding primitive %s", primitive)
-        statement = primitive.clone(test_case)
+        statement = primitive.clone(test_case, {})
         return test_case.add_statement(statement, position)
 
     def insert_random_statement(
@@ -542,7 +588,7 @@ class TestFactory:
             and not var.is_type_unknown()
             and not isinstance(
                 test_case.get_statement(var.get_statement_position()),
-                prim.NoneStatement,
+                stmt.NoneStatement,
             )
         ]
 
@@ -722,23 +768,19 @@ class TestFactory:
             parameters = self._get_reuse_parameters(
                 test_case, method.inferred_signature, position
             )
-            replacement = par_stmt.MethodStatement(
-                test_case, method, callee, parameters
-            )
+            replacement = stmt.MethodStatement(test_case, method, callee, parameters)
         elif call.is_constructor():
             constructor = cast(gao.GenericConstructor, call)
             parameters = self._get_reuse_parameters(
                 test_case, constructor.inferred_signature, position
             )
-            replacement = par_stmt.ConstructorStatement(
-                test_case, constructor, parameters
-            )
+            replacement = stmt.ConstructorStatement(test_case, constructor, parameters)
         elif call.is_function():
             funktion = cast(gao.GenericFunction, call)
             parameters = self._get_reuse_parameters(
                 test_case, funktion.inferred_signature, position
             )
-            replacement = par_stmt.FunctionStatement(test_case, funktion, parameters)
+            replacement = stmt.FunctionStatement(test_case, funktion, parameters)
 
         if replacement is None:
             assert False, f"Unhandled call type {call}"
@@ -783,7 +825,7 @@ class TestFactory:
             for var in variables
             if not isinstance(
                 test_case.get_statement(var.get_statement_position()),
-                prim.NoneStatement,
+                stmt.NoneStatement,
             )
         ]
         if len(variables) == 0:
@@ -1104,9 +1146,9 @@ class TestFactory:
         position: int,
         recursion_depth: int,
         allow_none: bool,
-        type_generators: Set[GenericAccessibleObject],
+        type_generators: OrderedSet[gao.GenericAccessibleObject],
     ) -> Optional[vr.VariableReference]:
-        type_generator = randomness.choice(list(type_generators))
+        type_generator = randomness.choice(type_generators)
         return self.append_generic_accessible(
             test_case,
             type_generator,
@@ -1139,7 +1181,7 @@ class TestFactory:
         position: int,
         recursion_depth: int,
     ) -> vr.VariableReference:
-        statement = prim.NoneStatement(test_case, parameter_type)
+        statement = stmt.NoneStatement(test_case, parameter_type)
         test_case.add_statement(statement, position)
         ret = test_case.get_statement(position).ret_val
         ret.distance = recursion_depth
@@ -1153,15 +1195,15 @@ class TestFactory:
         recursion_depth: int,
     ) -> vr.VariableReference:
         if parameter_type == int:
-            statement: prim.PrimitiveStatement = prim.IntPrimitiveStatement(test_case)
+            statement: stmt.PrimitiveStatement = stmt.IntPrimitiveStatement(test_case)
         elif parameter_type == float:
-            statement = prim.FloatPrimitiveStatement(test_case)
+            statement = stmt.FloatPrimitiveStatement(test_case)
         elif parameter_type == bool:
-            statement = prim.BooleanPrimitiveStatement(test_case)
+            statement = stmt.BooleanPrimitiveStatement(test_case)
         elif parameter_type == bytes:
-            statement = prim.BytesPrimitiveStatement(test_case)
+            statement = stmt.BytesPrimitiveStatement(test_case)
         else:
-            statement = prim.StringPrimitiveStatement(test_case)
+            statement = stmt.StringPrimitiveStatement(test_case)
         ret = test_case.add_statement(statement, position)
         ret.distance = recursion_depth
         return ret
@@ -1214,9 +1256,9 @@ class TestFactory:
                 elements.append(var)
             position += test_case.size() - previous_length
         collection_stmt = (
-            coll_stmt.ListStatement(test_case, parameter_type, elements)
+            stmt.ListStatement(test_case, parameter_type, elements)
             if parameter_type == list or get_origin(parameter_type) == list
-            else coll_stmt.SetStatement(test_case, parameter_type, elements)
+            else stmt.SetStatement(test_case, parameter_type, elements)
         )
         ret = test_case.add_statement(collection_stmt, position)
         ret.distance = recursion_depth
@@ -1249,7 +1291,7 @@ class TestFactory:
                 elements.append(var)
             position += test_case.size() - previous_length
         ret = test_case.add_statement(
-            coll_stmt.TupleStatement(test_case, parameter_type, elements), position
+            stmt.TupleStatement(test_case, parameter_type, elements), position
         )
         ret.distance = recursion_depth
         return ret
@@ -1287,7 +1329,7 @@ class TestFactory:
                 elements.append((key, value))
 
         ret = test_case.add_statement(
-            coll_stmt.DictStatement(test_case, parameter_type, elements), position
+            stmt.DictStatement(test_case, parameter_type, elements), position
         )
         ret.distance = recursion_depth
         return ret
